#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   server_createCaseTemp.py
#
#       指定したcaseをコピーしてtempケースを指定した場所に作成する。
#
#   17/04/19    新規作成
#      07/12    createTempCase, createTempCase:転送するfileに「include」folder内のfileを追加
#

import os
import sys
import glob
import server_getFoamContents

#
#  getTempFolderName
#    tempFolder名を取得する
def getTempFolderName(caseName):
    Nos = []
    folders = glob.glob(os.path.expanduser("~/TreeFoamServer/tmp/server_*"))
    for folder in folders:
        if os.path.isdir(folder) == True:
            name = folder.split("/")[-1]
            No = name.split("_")[1]
            try:
                a = int(No)
                Nos.append(a)
            except:
                pass
    if len(Nos) == 0:
        caseNo = "0"
    else:
        caseNo = str(max(Nos) + 1)
    tempFolderName = "server_" + caseNo + "_" + caseName
    return tempFolderName

#
#  getTimeFolders
#    timeFoldersを取得
def getTimeFolders(caseDir):
    timeFolders = []
    folders = glob.glob(caseDir+"/*")
    for folder in folders:
        if os.path.isdir(folder) == True:
            timeFolder = folder.split("/")[-1]
            try:
                a = float(timeFolder)
                timeFolders.append(timeFolder)
            except:
                pass
    return timeFolders

#
#  creaeTempFolder
#    tempFolderを作成する
def createTempFolder(tempDir, caseDir, numFolder):
    caseName = caseDir.split("/")[-1]
    numDir = tempDir + "/" + caseName + "/" + numFolder
    if len(glob.glob(tempDir)) != 0:
        if len(glob.glob(numDir)) != 0:
            comm = "rm -rf " + numDir
            os.system(comm)
    else:
        comm = "mkdir " + tempDir
        os.system(comm)
        comm = "mkdir " + tempDir + "/" + caseName
        os.system(comm)
    if len(glob.glob(tempDir + "/" + caseName + "/constant")) == 0:
        comm = "mkdir " + tempDir + "/" + caseName + "/constant"
        os.system(comm)
    if len(glob.glob(tempDir + "/" + caseName + "/constant/polyMesh")) == 0:
        comm = "mkdir " + tempDir + "/" + caseName + "/constant/polyMesh"
        os.system(comm)
    if len(glob.glob(tempDir + "/" + caseName + "/system")) == 0:
        comm = "mkdir " + tempDir + "/" + caseName + "/system"
        os.system(comm)
    if len(glob.glob(tempDir + "/" + caseName + "/include")) == 0:
        comm = "mkdir " + tempDir + "/" + caseName + "/include"
        os.system(comm)
    fileName = tempDir + "/caseDir"
    f = open(fileName, "w")
    f.write(caseDir)
    f.close()
    timeFolders = getTimeFolders(caseDir)
    fileName = tempDir + "/timeFolders"
    f = open(fileName, "w")
    f.write(" ".join(timeFolders))
    f.close()
    return

#
#  checkCreateDir
#    pasteDirをチェック
def checkCreateDir(tempCaseDir, pasteDir):
    words = pasteDir[len(tempCaseDir)+1:].split("/")
    tempDir = tempCaseDir
    for word in words:
        tempDir += "/" + word
        if len(glob.glob(tempDir)) == 0:
            os.system("mkdir " + tempDir)
    return

#
#  createTempCase
#    tempCaseの作成
def createTempCase(tempDir, caseDir, numFolder):
    copyFiles = []
    caseName = caseDir.split("/")[-1]
    #boundaryをコピー
    if len(glob.glob(caseDir + "/constant/polyMesh/boundary")) != 0:
        source = caseDir + "/constant/polyMesh/boundary"
        copyFiles.append(source)
    folders = glob.glob(caseDir + "/constant/*")
    for folder in folders:
        if len(glob.glob(folder + "/polyMesh/boundary")) != 0:
            copyFiles.append(folder + "/polyMesh/boundary")
    #controlDictをコピー
    if len(glob.glob(caseDir + "/system/controlDict")) != 0:
        copyFiles.append(caseDir + "/system/controlDict")
    #include内のfileをコピー
    if len(glob.glob(caseDir + "/include/*")) != 0:
        files = glob.glob(caseDir + "/include/*")
        copyFiles += files
    #numFolderをコピー
    try:
        a = float(numFolder)
        flag = 1
    except:
        flag = 0
    if flag == 0:
        return
    #  numFolder内のファイルをコピー
    #copyFiles = []
    folders = []
    numDir = caseDir + "/" + numFolder
    foldersFiles = glob.glob(numDir + "/*")
    for folderFile in foldersFiles:
        if os.path.isfile(folderFile) == True:
            copyFiles.append(folderFile)
        elif os.path.isdir(folderFile) == True:
            folders.append(folderFile)

    for folder in folders:
        if folder.split("/")[-1] == "polyMesh":
            if len(glob.glob(folder + "/polyMesh/boundary")) != 0:
                copyFiles.append(folder + "/polyMesh/boundary")
        else:
            files = glob.glob(folder + "/*")
            for name in files:
                if os.path.isfile(name) == True:
                    copyFiles.append(name)
                else:
                    if name.split("/")[-1] == "polyMesh":
                        if len(glob.glob(name + "/polyMesh/boundary")) != 0:
                            copyFiles.append(name + "/polyMesh/boundary")

    tempCaseDir = tempDir + "/" + caseName
    for copyFile in copyFiles:
        pasteFile = tempCaseDir + copyFile[len(caseDir):]
        pasteDir = "/".join(pasteFile.split("/")[:-1])
        checkCreateDir(tempCaseDir, pasteDir)
        comm = "cp -rf " + copyFile + " " + pasteDir
        os.system(comm)


#メイン
if __name__ == "__main__":
    caseDir = sys.argv[1]
    numFolder = sys.argv[2]
    #dirを整形
    caseDir = os.path.expanduser(caseDir)
    caseDir = os.path.abspath(caseDir)
    caseName = caseDir.split("/")[-1]
    #tempFolder作成
    #  tempFolder名を取得
    tempFolderName = getTempFolderName(caseName)
    #tempFolder名を出力
    print tempFolderName
    tempDir = "~/TreeFoamServer/tmp/" + tempFolderName
    tempDir = os.path.expanduser(tempDir)
    createTempFolder(tempDir, caseDir, numFolder)
    #tempCaseを作成
    createTempCase(tempDir, caseDir, numFolder)



